require "util"

artillery_extension =
{
  filename = "__Artillery__/graphics/turretelevation.png",
  priority = "medium",
  width = 256,
  height = 256,
  direction_count = 4,
  frame_count = 8,
  axially_symmetrical = false,
  shift = {0.15, -1.0}
}

data:extend({

   {
    type = "ammo-turret",
    name = "artillery",
    icon = "__Artillery__/graphics/icon.png",
    flags = {"placeable-player", "player-creation"},
    minable = {mining_time = 0.5, result = "artillery"},
    max_health = 1500,
    corpse = "small-remnants",
    collision_box = {{-1.2, -1.2 }, {1.2, 1.2}},
    selection_box = {{-1.3, -1.3 }, {1.3, 1.3}},
    rotation_speed = 0.0005,
    preparing_speed = 0.01,
    folding_speed = 0.01,
    dying_explosion = "huge-explosion",
    inventory_size = 1,
    automated_ammo_count = 10,
    folded_animation = (function()
                          local res = util.table.deepcopy(artillery_extension)
                          res.frame_count = 1
                          res.line_length = 1
                          return res
                       end)(),
    preparing_animation = artillery_extension,
    prepared_animation =
    {
      filename = "__Artillery__/graphics/turretrotation.png",
      priority = "medium",
      width = 256,
      height = 256,
      direction_count = 64,
      frame_count = 1,
      line_length = 8,
      axially_symmetrical = false,
      shift = {0.15, -1.0}
    },
    folding_animation = (function()
                          local res = util.table.deepcopy(artillery_extension)
                          res.run_mode = "backward"
                          return res
                       end)(),
    base_picture =
    {
      filename = "__Artillery__/graphics/base.png",
      priority = "high",
      width = 256,
      height = 256,
      shift = {0.15, -1.0}
    },
    attack_parameters =
    {
      ammo_category = "cannon-shell",
      cooldown = 500,
      projectile_center = {0.15, -1.3},
      projectile_creation_distance = 3.0,
      range = 200,
      sound = {{filename = "__base__/sound/explosion2.ogg", volume = 2.0}},
    }
  },

  {
    type = "projectile",
    name = "artilleryshell",
    flags = {"not-on-map"},
    acceleration = 0.0,
	action =
	{
		{
			type = "area",
			perimeter = 10,
			action_delivery =
			{
				type = "instant",
				target_effects =
				{
					{
					type = "damage",
					damage = {amount = 100, type = "physical"}
					},
					{
					type = "damage",
					damage = {amount = 40, type = "explosion"}
					},
					{
					type = "create-entity",
					entity_name = "explosion"
					}
				}
			}
		},
		{
			type = "direct",
			action_delivery = 
			{
				type = "instant",
				target_effects =
				{
					{
					type = "create-entity",
					entity_name = "huge-explosion"
					},
					{
					type = "create-entity",
					entity_name = "small-scorchmark",
					check_buildability = true
					}
				}
			}
		}
	},
	light = {intensity = 0.5, size = 6},
    animation =
    {
        filename = "__Artillery__/graphics/shell.png",
        priority = "extra-high",
        width = 10,
        height = 30,
        frame_count = 1
    },
    shadow =
    {
        filename = "__Artillery__/graphics/shell-shadow.png",
        priority = "extra-high",
        width = 10,
        height = 30,
        frame_count = 1
    }
  },
  
  {
	type = "projectile",
	name = "muzzle-flash",
	flags = {"not-on-map"},
	acceleration = 0.0,
	animation = 
	{
        filename = "__base__/graphics/entity/huge-explosion/huge-explosion.png",
        priority = "extra-high",
        width = 112,
        height = 94,
        frame_count = 54,
		line_length = 6,
        animation_speed = 1	
	},
	light = {intensity = 0.5, size = 6}

  }
})